@@ -160,9 +160,9 @@ where
         ITER: Iterator<Item = I>,
         F: FnMut(bool, &'b mut SingleApp<S, SS, P>) -> Result<R>,
     {
-        let args: Vec<String> = iter.map(|v| v.into()).collect();
+        let args = iter.map(|v| v.into());
         let parser = &mut self.parser;
-        let ret = parser.parse(&mut ArgStream::from(args.into_iter()))?;
+        let ret = parser.parse(&mut ArgStream::from(args))?;
 
         r(ret, self)
     }
@@ -210,11 +210,11 @@ where
         FUT: Future<Output = Result<R>>,
         F: FnMut(bool, &'b mut SingleApp<S, SS, P>) -> FUT,
     {
-        let args: Vec<String> = iter.map(|v| v.into()).collect();
+        let args = iter.map(|v| v.into());
         let parser = &mut self.parser;
         let async_ret;
 
-        match parser.parse(&mut ArgStream::from(args.into_iter())) {
+        match parser.parse(&mut ArgStream::from(args)) {
             Ok(ret) => {
                 let ret = r(ret, self).await;
 
@@ -269,9 +269,9 @@ where
         ITER: Iterator<Item = I>,
         F: FnMut(bool, SingleApp<S, SS, P>) -> Result<R>,
     {
-        let args: Vec<String> = iter.map(|v| v.into()).collect();
+        let args = iter.map(|v| v.into());
         let parser = &mut self.parser;
-        let ret = parser.parse(&mut ArgStream::new(args.into_iter()))?;
+        let ret = parser.parse(&mut ArgStream::new(args))?;
 
         r(ret, std::mem::take(self))
     }
@@ -314,11 +314,11 @@ where
         FUT: Future<Output = Result<R>>,
         F: FnMut(bool, SingleApp<S, SS, P>) -> FUT,
     {
-        let args: Vec<String> = iter.map(|v| v.into()).collect();
+        let args = iter.map(|v| v.into());
         let parser = &mut self.parser;
         let async_ret;
 
-        match parser.parse(&mut ArgStream::from(args.into_iter())) {
+        match parser.parse(&mut ArgStream::from(args)) {
             Ok(ret) => {
                 let ret = r(ret, std::mem::take(self)).await;
 
