@@ -347,10 +347,10 @@ pub fn gstr(s: &str) -> ustr::Ustr {
     ustr::Ustr::from(s)
 }
 
-pub fn getopt_dynparser<'a, I, ITER, S, SS>(
+pub fn getopt_dynparser<I, ITER, S, SS>(
     iter: ITER,
-    parsers: Vec<&'a mut DynParser<S, SS>>,
-) -> Result<Option<&'a mut DynParser<S, SS>>>
+    parsers: Vec<&mut DynParser<S, SS>>,
+) -> Result<Option<&mut DynParser<S, SS>>>
 where
     I: Into<String>,
     ITER: Iterator<Item = I>,
@@ -383,10 +383,10 @@ where
     Ok(None)
 }
 
-pub fn getopt_parser<'a, I, ITER, S, SS, P>(
+pub fn getopt_parser<I, ITER, S, SS, P>(
     iter: ITER,
-    parsers: Vec<&'a mut Parser<S, SS, P>>,
-) -> Result<Option<&'a mut Parser<S, SS, P>>>
+    parsers: Vec<&mut Parser<S, SS, P>>,
+) -> Result<Option<&mut Parser<S, SS, P>>>
 where
     I: Into<String>,
     ITER: Iterator<Item = I>,
@@ -578,12 +578,85 @@ pub use aopt_macro::getopt;
 /// Generate help message of Set.
 pub use aopt_macro::getopt_help;
 
+/// Add option to `Parser`.
+///
+/// # Example
+/// ```rust
+/// use aopt::err::Result;
+/// use aopt::prelude::*;
+///
+/// fn main() -> Result<()> {
+///     let mut parser = ForwardParser::default();
+///
+///     getopt_add!(parser, "--aopt=s!", "Help message of aopt")?;
+///     getopt_add!(
+///         parser,
+///         "--bopt=b",
+///         alias = "-b",
+///         help = "Help message of bopt"
+///     )?;
+///     getopt_add!(parser, "--copt=a", name = "选项c", prefix = "-")?;
+///     getopt_add!(
+///         parser,
+///         "--dopt=b/",
+///         "Help message of dopt",
+///         simple_opt_cb!(|_, _, v| {
+///             assert_eq!(v, OptValue::from(false));
+///             Ok(Some(v))
+///         })
+///     )?;
+///     getopt_add!(
+///         parser,
+///         "--eopt=i",
+///         callback = simple_opt_cb!(|_, _, v| {
+///             assert_eq!(v, OptValue::from(42i64));
+///             Ok(Some(v))
+///         })
+///     )?;
+///     getopt_add!(
+///         parser,
+///         "fopt=p",
+///         index = OptIndex::forward(1),
+///         callback = simple_pos_cb!(|_, _, arg, _, v| {
+///             assert_eq!(arg, "foo");
+///             Ok(Some(v))
+///         })
+///     )?;
+///     getopt_add!(parser, "--gopt=u", default = OptValue::from(42u64))?;
+///     getopt_add!(
+///         parser,
+///         "hopt=m",
+///         callback = simple_main_cb!(|_, set: &SimpleSet, _, v| {
+///             assert_eq!(set["--aopt"].get_help(), "Help message of aopt");
+///             assert_eq!(set["--bopt"].get_help(), "Help message of bopt");
+///             assert_eq!(set["--dopt"].get_help(), "Help message of dopt");
+///             assert_eq!(set["选项c"].get_name(), "选项c");
+///             assert_eq!(set["选项c"].get_prefix(), "-");
+///             assert_eq!(set["gopt"].get_value(), &OptValue::from(42u64));
+///             assert_eq!(set["aopt"].get_value(), &OptValue::from("bar"));
+///             assert_eq!(set["bopt"].get_value(), &OptValue::from(true));
+///             Ok(Some(v))
+///         })
+///     )?;
+///     getopt!(
+///         &mut ["--aopt", "bar", "-b", "foo", "--/dopt", "--eopt=42"]
+///             .iter()
+///             .map(|&v| String::from(v)),
+///         parser,
+///     )?;
+///
+///     Ok(())
+/// }
+/// ```
+pub use aopt_macro::getopt_add;
+
 pub mod prelude {
     pub use crate::arg::ArgStream;
     pub use crate::ctx::Context;
     pub use crate::ctx::NonOptContext;
     pub use crate::ctx::OptContext;
     pub use crate::getopt;
+    pub use crate::getopt_add;
     pub use crate::getopt_dynparser;
     pub use crate::getopt_help;
     pub use crate::getopt_parser;
@@ -636,6 +709,7 @@ pub mod prelude {
     pub use crate::proc::NonOptMatcher;
     pub use crate::proc::OptMatcher;
     pub use crate::proc::Proc;
+    pub use crate::set::CreateInfo;
     pub use crate::set::CreatorSet;
     pub use crate::set::OptionSet;
     pub use crate::set::PrefixSet;
