@@ -49,11 +49,11 @@ impl TryFrom<CreateInfo> for BoolOpt {
         let help_info = HelpInfo::from(&mut ci);
         let prefix = ci
             .get_prefix()
-            .ok_or(Error::opt_missing_prefix(ci.get_name(), ci.get_type_name()))?;
+            .ok_or_else(|| Error::opt_missing_prefix(ci.get_name(), ci.get_type_name()))?;
 
         Ok(Self {
             uid: ci.get_uid(),
-            name: ci.get_name().clone(),
+            name: ci.get_name(),
             prefix,
             optional: ci.get_optional(),
             value: OptValue::default(),
@@ -80,10 +80,7 @@ impl Type for BoolOpt {
     }
 
     fn match_style(&self, style: Style) -> bool {
-        match style {
-            Style::Boolean | Style::Multiple => true,
-            _ => false,
-        }
+        matches!(style, Style::Boolean | Style::Multiple)
     }
 
     fn check(&self) -> Result<()> {
@@ -119,10 +116,7 @@ impl Callback for BoolOpt {
     }
 
     fn is_accept_callback_type(&self, callback_type: CallbackType) -> bool {
-        match callback_type {
-            CallbackType::Opt | CallbackType::OptMut => true,
-            _ => false,
-        }
+        matches!(callback_type, CallbackType::Opt | CallbackType::OptMut)
     }
 
     fn set_callback_ret(&mut self, ret: Option<OptValue>) -> Result<()> {
@@ -239,7 +233,7 @@ impl Value for BoolOpt {
 
     fn parse_value(&self, _string: Ustr, disable: bool, _index: u64) -> Result<OptValue> {
         if !self.is_deactivate_style() && disable {
-            return Err(Error::sp_unsupport_deactivate_style(self.get_hint()));
+            Err(Error::sp_unsupport_deactivate_style(self.get_hint()))
         } else {
             Ok(OptValue::from(!self.is_deactivate_style()))
         }
@@ -288,12 +282,10 @@ impl Creator for BoolCreator {
     }
 
     fn create_with(&self, create_info: CreateInfo) -> Result<Box<dyn Opt>> {
-        if create_info.get_support_deactivate_style() {
-            if !self.is_support_deactivate_style() {
-                return Err(Error::opt_unsupport_deactivate_style(
-                    create_info.get_name(),
-                ));
-            }
+        if create_info.get_support_deactivate_style() && !self.is_support_deactivate_style() {
+            return Err(Error::opt_unsupport_deactivate_style(
+                create_info.get_name(),
+            ));
         }
 
         assert_eq!(create_info.get_type_name(), self.get_type_name());
