@@ -287,59 +287,35 @@ impl Value {
     }
 
     pub fn is_int(&self) -> bool {
-        match self {
-            Self::Int(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Int(_))
     }
 
     pub fn is_uint(&self) -> bool {
-        match self {
-            Self::Uint(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Uint(_))
     }
 
     pub fn is_flt(&self) -> bool {
-        match self {
-            Self::Flt(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Flt(_))
     }
 
     pub fn is_str(&self) -> bool {
-        match self {
-            Self::Str(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Str(_))
     }
 
     pub fn is_bool(&self) -> bool {
-        match self {
-            Self::Bool(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Bool(_))
     }
 
     pub fn is_vec(&self) -> bool {
-        match self {
-            Self::Array(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Array(_))
     }
 
     pub fn is_any(&self) -> bool {
-        match self {
-            Self::Any(_) => true,
-            _ => false,
-        }
+        matches!(self, Self::Any(_))
     }
 
     pub fn is_null(&self) -> bool {
-        match self {
-            Self::Null => true,
-            _ => false,
-        }
+        matches!(self, Self::Null)
     }
 
     pub fn reset(&mut self) {
@@ -348,24 +324,18 @@ impl Value {
 
     /// Add string if current value is [`Value::Array`].
     pub fn add_str(&mut self, string: String) -> &mut Self {
-        match self {
-            Self::Array(v) => {
-                v.push(string);
-            }
-            _ => {}
+        if let Self::Array(v) = self {
+            v.push(string);
         }
         self
     }
 
     /// Append string if current value is [`Value::Array`].
     pub fn app_str(&mut self, values: &[String]) -> &mut Self {
-        match self {
-            Self::Array(v) => {
-                for value in values {
-                    v.push(value.clone());
-                }
+        if let Self::Array(v) = self {
+            for value in values {
+                v.push(value.clone());
             }
-            _ => {}
         }
         self
     }
@@ -489,10 +459,9 @@ impl Debug for CloneHelper {
 impl PartialEq for Value {
     fn eq(&self, other: &Self) -> bool {
         match self {
-            Self::Null => match other {
-                Self::Null => true,
-                _ => false,
-            },
+            Self::Null => {
+                matches!(other, Self::Null)
+            }
             Value::Int(v) => match other {
                 Self::Int(ov) => *v == *ov,
                 _ => false,
