@@ -51,7 +51,7 @@ impl<S: Set, SS: Service<S>> Policy<S, SS> for ForwardPolicy {
         iter: &mut dyn Iterator<Item = Argument>,
     ) -> Result<bool> {
         // copy the prefix, so we don't need borrow set
-        let prefix: Vec<Ustr> = set.get_prefix().iter().map(|v| v.clone()).collect();
+        let prefix: Vec<Ustr> = set.get_prefix().to_vec();
         let mut iter = iter.enumerate();
 
         // add info to Service
@@ -87,7 +87,7 @@ impl<S: Set, SS: Service<S>> Policy<S, SS> for ForwardPolicy {
                     debug!(?arg, "after parsing ...");
                     for gen_style in &parser_state {
                         if let Some(mut proc) =
-                            service.gen_opt::<OptMatcher>(&arg, &gen_style, index as u64)?
+                            service.gen_opt::<OptMatcher>(&arg, gen_style, index as u64)?
                         {
                             service.matching(&mut proc, set, true)?;
 
@@ -117,7 +117,7 @@ impl<S: Set, SS: Service<S>> Policy<S, SS> for ForwardPolicy {
             } else if !matched {
                 debug!("!!! {:?} not matching, will add it to noa", &arg);
                 if let Some(noa) = &arg.current {
-                    service.get_noa_mut().push(noa.clone());
+                    service.get_noa_mut().push(*noa);
                 }
             }
         }
@@ -185,7 +185,7 @@ mod test {
     use crate::prelude::*;
 
     #[test]
-    fn testing_simple_parser() {
+    fn testing_forward_parser() {
         assert!(do_simple_test().is_ok());
         assert!(do_simple_test_failed().is_err());
         assert!(do_simple_test_failed_non_strict().is_ok());
