@@ -1,3 +1,5 @@
+use std::ops::Not;
+
 use crate::arg::Argument;
 use crate::ctx::Context;
 use crate::ctx::NonOptContext;
@@ -53,8 +55,8 @@ impl ParserState {
     }
 
     fn do_unwrap(name: &str, value: &Option<Ustr>) -> Result<Ustr> {
-        let string = value.as_ref().ok_or(Self::gen_unwrap_error(name))?;
-        Ok(string.clone())
+        let string = value.as_ref().ok_or_else(|| Self::gen_unwrap_error(name))?;
+        Ok(*string)
     }
 
     pub fn gen_opt<M: Matcher + Default>(
@@ -70,7 +72,7 @@ impl ParserState {
                     ret.push(Box::new(OptContext::new(
                         Self::do_unwrap("prefix", arg.get_prefix())?,
                         Self::do_unwrap("name", arg.get_name())?,
-                        arg.get_value().clone(),
+                        *arg.get_value(),
                         Style::Argument,
                         false,
                         arg.is_disabled(),
@@ -83,7 +85,7 @@ impl ParserState {
                     ret.push(Box::new(OptContext::new(
                         Self::do_unwrap("prefix", arg.get_prefix())?,
                         Self::do_unwrap("name", arg.get_name())?,
-                        arg.next.clone(),
+                        arg.next,
                         Style::Argument,
                         true,
                         arg.is_disabled(),
@@ -147,7 +149,7 @@ impl ParserState {
                     ret.push(Box::new(OptContext::new(
                         Self::do_unwrap("prefix", arg.get_prefix())?,
                         Self::do_unwrap("name", arg.get_name())?,
-                        arg.get_value().clone(),
+                        *arg.get_value(),
                         Style::Argument,
                         false,
                         arg.is_disabled(),
@@ -160,7 +162,7 @@ impl ParserState {
                     ret.push(Box::new(OptContext::new(
                         Self::do_unwrap("prefix", arg.get_prefix())?,
                         Self::do_unwrap("name", arg.get_name())?,
-                        arg.next.clone(),
+                        arg.next,
                         Style::Argument,
                         true,
                         arg.is_disabled(),
@@ -221,17 +223,15 @@ impl ParserState {
             }
             _ => {}
         }
-        Ok(if ret.len() == 0 {
-            None
-        } else {
+        Ok(ret.is_empty().not().then(|| {
             let mut proc = M::default();
 
             for item in ret {
                 proc.add_ctx(item);
             }
 
-            Some(proc)
-        })
+            proc
+        }))
     }
 
     pub fn gen_nonopt<M: Matcher + Default>(
@@ -245,7 +245,7 @@ impl ParserState {
         match self {
             Self::PSNonMain => {
                 ret.push(Box::new(NonOptContext::new(
-                    noa.clone(),
+                    *noa,
                     Style::Main,
                     total,
                     current,
@@ -253,7 +253,7 @@ impl ParserState {
             }
             Self::PSNonPos => {
                 ret.push(Box::new(NonOptContext::new(
-                    noa.clone(),
+                    *noa,
                     Style::Pos,
                     total,
                     current,
@@ -261,7 +261,7 @@ impl ParserState {
             }
             Self::PSNonCmd => {
                 ret.push(Box::new(NonOptContext::new(
-                    noa.clone(),
+                    *noa,
                     Style::Cmd,
                     total,
                     current,
@@ -269,16 +269,14 @@ impl ParserState {
             }
             _ => {}
         }
-        Ok(if ret.len() == 0 {
-            None
-        } else {
+        Ok(ret.is_empty().not().then(|| {
             let mut proc = M::default();
 
             for item in ret {
                 proc.add_ctx(item);
             }
 
-            Some(proc)
-        })
+            proc
+        }))
     }
 }
